# MiniContourFinder
### Lightweight image segmentation software for biological images
Full documentation can be found on [Read the Docs](https://minicontourfinder.readthedocs.io/en/latest/).

Image segmentation has become a common task throughout biological and biomedical sciences. Despite the growth in image use, much of image analysis is still done manually, which frequently causes a bottleneck in data collection. MiniContourFinder is a lightweight image segmentation tool built in Python with OpenCV. MiniContourFinder was designed to allow users with minimal command line experience or image processing expertise to generate accurate and reproducible segmentations.

**Availability and implementation**

MiniContourFinder is free and open-source software available under the GNU General Public License v3.0. MiniContourFinder can be installed via Python package installer pip, the Conda package management system, or the source code above. 
